@@ -52,6 +52,7 @@ static size_t loop;
   787399
 */
 
+/* *INDENT-OFF* */
 static const struct {
   const char *user;
   const char *passwd;
@@ -76,13 +77,13 @@ static const struct {
   { "user3", "512368", PAM_AUTH_ERR },
   { "user3", "787399", PAM_SUCCESS },
 };
+/* *INDENT-ON* */
 
 static int
 oath_conv (int num_msg, const struct pam_message **msg,
 	   struct pam_response **resp, void *appdata_ptr)
 {
   struct pam_response *out;
-  size_t i;
 
   if (num_msg != 1)
     {
@@ -127,7 +128,7 @@ main (int argc, char **argv)
       rc = pam_authenticate (pamh, 0);
       if (rc != tv[loop].expectrc)
 	{
-	  printf ("pam_authenticate[%d] %d\n", loop, rc);
+	  printf ("pam_authenticate[%ld] %d\n", loop, rc);
 	  return 1;
 	}
 
